@@ -111,9 +111,9 @@ def setup_partitions(board_config, media, image_size, bootfs_label,
         image_size_in_bytes = convert_size_to_bytes(image_size)
         cylinders = image_size_in_bytes / CYLINDER_SIZE
         proc = cmd_runner.run(
-            ['qemu-img', 'create', '-f', 'raw', media.path,
-             str(image_size_in_bytes)],
-            stdout=open('/dev/null', 'w'))
+            ['dd', 'of=%s' % media.path,
+             'bs=1', 'seek=%s' % image_size_in_bytes, 'count=0'],
+            stderr=open('/dev/null', 'w'))
         proc.wait()
 
     if should_create_partitions:
@@ -330,6 +330,9 @@ def _get_udisks_device_path(device):
 def convert_size_to_bytes(size):
     """Convert a size string in Kbytes, Mbytes or Gbytes to bytes."""
     unit = size[-1].upper()
+    # no unit? (ends with a digit)
+    if unit in '0123456789':
+        return int(size)
     real_size = int(size[:-1])
     if unit == 'K':
         real_size = real_size * 1024
